<?php

/*
 * @file
 *
 * This is the class file for the browser data presentation.  Essentially, it manages targetted links,
 * but has the potential to be expanded to include useful variations.
 *
 * Mostly, however, this is an example of an "alternative to Litebox" presentation class which assisted
 * in testing the various data source classes to make sure they operated when there were multiple
 * presentations.
 */

class ShowMePresentation_browser extends ShowMePresentation {

  public function supportedTypeList() { return array('text/*'); }

  public function getTitle() { 
    if ($this->getVariant() == 'minimal')
      return t('Open Browser (minimal frame)');
    return t('Open Browser (full featured)');
  }

  function getAnchorHTML($element, $sourceobj) {
    $node = $element['#node'];
    $item = $element['#item'];

    // See if the source object can provide us with an actual image.  If so, use it, as browser
    // has special direct support for images.

    $metadata = $sourceobj->getMetadataFromElement($element);
    $url = $sourceobj->getTargetURL($element, 'text/html');

    // We do all the work with window.open.   It doesn't degrade well, and creating a fallback to use
    // standard targetted windows would be nice.

    if ( !($metadata->height && $metadata->width) ) {
      $metadata->width = 800;
      $metadata->height = 600;
    }

    $jsattrs = array();

    if ($this->getVariant() == 'minimal') {
      $jsattrs = array('status=no', 'toolbar=no', 'location=no', 'menubar=no', 'directories=no');
    }

    $jsattrs[] = 'height='.($metadata->height + 16);
    $jsattrs[] = 'width='.($metadata->width + 16);

    $link_attributes = array(
      'onclick' => "window.open('" . $url . "','showme_browser','" . implode(',', $jsattrs) . "')",
    );

    return '<a href="#" onclick="' . $link_attributes['onclick'] . '">' . 
      $sourceobj->getAnchorContentHTML($element) . '</a>';
  }
}

/*
 * Implements hook_showme_object_factory().
 */

function showme_browser_showme_object_factory($objkey) {
  return new ShowMePresentation_browser($objkey);
}
