<?php

/*
 * @file
 *
 * Class implementation for image popups.   This is quite complete as is, though I can imagine
 * some metadata enhancements.  
 */

class ShowMeDataSource_imagefield extends ShowMeDataSource {

  function supportedTypeList() { return array('image/*', 'text/html'); }
  function supportedFieldTypes() { return array('image', 'filefield'); }

  public function getTitle() { 
    $parts = explode(',', $this->getVariant());
    return $parts[0] . ' -> ' . $parts[1];
  }

  /*
   * Implements getContent().
   *
   * Since we support both image and text/html, we will need to be careful.  In our case, we will 
   * return only text/html because there is no point in returning raw image data.   If you think 
   * about it, returning raw data from database blobs makes sense, but that's the future...
   *
   * In our case, we return a themed image in the source type
   */

  public function getContent($element, $mimetype) {
    if (substr($mimetype, 0, 5) == 'text/') {
      return $this->_format_image(1, $element['#node'], $element['#field_name'], $element['#item']);
    }
  }

  /* 
   * This overridden getAnchorContentHTML works like getContent, except it uses the source preset
   */
  
  public function getAnchorContentHTML($element) {
    return $this->_format_image(0, $element['#node'], $element['#field_name'], $element['#item']);
  }

  /* 
   * Internal function to format images using either the source or destination format index
   */

  private function _format_image($presetindex, $node, $field_name, $item) {
    $parts = explode(',', $this->getVariant());
    $presetname = $parts[$presetindex];

    $this->_massage_item($item);

    if ( ($preset = imagecache_preset_by_name($presetname)) ) {
      return theme('imagecache', $presetname, $item['filepath'], $data['alt'], $node->title);
    }
  }

  /*
   * getTargetURL is interesting.  In the case where we want text/html, then we can use the inherited
   * version, which simply constructs a drupal URL to the page which will have code inserted to display
   * the image.   However, if a raw image is needed, then we pass back the URL to the image itself.
   */

  public function getTargetURL($element, $mimetype) {
    if (substr($mimetype, 0, 5) == 'text/') {
      return parent::getTargetURL($element, $mimetype);
    }
    if (substr($mimetype, 0, 6) == 'image/') {
      $item = $element['#item'];

      $parts = explode(',', $this->getVariant());
      $presetname = $parts[1];

      $this->_massage_item($item);
      
      if ( ($preset = imagecache_preset_by_name($presetname)) ) {
        return imagecache_create_url($presetname, $item['filepath']);
      }
    }
  }

  /*
   * Fill in relevant fields in item in preparation for use of $item
   */

  private function _massage_item(&$item) {
    // Some of this was lifted (thank you) from hook_field_formatter() in drupal/project/thickbox

    if (is_string($item['data'])) {
      $item['data'] = unserialize($item['data']);
    }
    if (!isset($item['filepath'])) {
      $file = field_file_load($item['fid']);
      $item['filepath'] = $file['filepath'];
    }
  }
}

/*
 * Implements hook_showme_object_factory().
 */

function showme_imagefield_showme_object_factory($objkey) {
    return new ShowMeDataSource_imagefield($objkey);
}
