<?php

/*
 * @file
 *
 * Class implementation for ShowMe links.   Creates a method to pass URLs to presentation spaces
 * from the link content type.   Some thought should go into how various link formatting is incorporated
 * into this, but otherwise works simply and effectively.
 */

class ShowMeDataSource_link extends ShowMeDataSource {

  function supportedTypeList() { return array('text/html'); }
  function supportedFieldTypes() { return array('link'); }

  function getTitle() { 
    return "Go to URL";
  }

  /*
   * Implements getContent().
   *
   * In theory, it often is unnecessary to check for mimetype.   Most information will be delivered in
   * a compatible form or else this object would not have been chosen by its caller.
   */

  function getContent($element, $mimetype) {
    if (substr($mimetype, 0, 5) == 'text/') {

      // None of the link formatters are quite right, we'll just make it up.   Of course, it would be great
      // to include all kinds of options, just as with showme_image, but that can be done later if this
      // has any utility.

      if ( !($title = $element['#item']['display_title']) ) {
        $title = $element['#item']['url'];
      }

      return $title . '>>';     // cheapo indicator to let people know a popup is coming
    }
  }

  /*
   * Implements getTargetURL().
   */

  public function getTargetURL($element, $mimetype) {
    return $element['#item']['url']; // is it really this simple?
  }

  /* 
   * Implements getMetadataFromElement().
   */

  public function getMetadataFromElement($element) {
    $metadata = parent::getMetadataFromElement($element);

    $metadata->width = 700;
    $metadata->height = 500;

    return $metadata;
  }

}

/*
 * Implements hook_showme_object_factory().
 */

function showme_link_showme_object_factory($objkey) {
    return new ShowMeDataSource_link($objkey);
}
