<?php

/*
 * @file
 *
 * Presentation implementation for Lytebox.
 *
 * Supports text and image displays with suggested sizes available from metadata.  Does not support
 * galleries yet, but not difficult to add.
 */

class ShowMePresentation_lytebox extends ShowMePresentation {

  public function supportedTypeList() { return array('text/*', 'image/*'); }
  public function getTitle() { return "Lytebox"; }

  function getAnchorHTML($element, $sourceobj) {
    $node = $element['#node'];
    $item = $element['#item'];

    // See if the source object can provide us with an actual image.  If so, use it, as lytebox
    // has special direct support for images.

    $useimage = $sourceobj->supportsMimeType('image/*');
    $metadata = $sourceobj->getMetadataFromElement($element);

    $link_attributes = array(
      'rel' => ($useimage? 'lytebox' : 'lyteframe'),
      'title' => $metadata->title,
    );

    // Add height and width if present

    if ($metadata->height && $metadata->width) {
      $link_attributes['rev'] = 'width:'.($metadata->width+16) . '; height:'.($metadata->height+16);
    }

    $url = $sourceobj->getTargetURL($element, $useimage? 'image/*' : 'text/html');

    return l($sourceobj->getAnchorContentHTML($element), $url,
             array('attributes' => $link_attributes, 'absolute' => FALSE, 'html' => TRUE));
  }

}

/*
 * Implements hook_showme_object_factory().
 */

function showme_lytebox_showme_object_factory($objkey) {
  showme_lytebox_add();		// add js
  return new ShowMePresentation_lytebox($objkey);
}
